# acq


### What it is?!

This library provides a simple and convenient way to
automatically search packages for modules and import them
without needing project files to manually import them, which
allows for automatic configuration and other useful mechanics
within projects.


### Contributing

Thank you for considering use of this project, and please feel
free to provide any suggestions in pull requests if you have
any!
